inline void FBB::TableBase::clear()
{
    d_tabulated = false;
    d_string.clear();
}
